.. _release:

{{ header }}

*************
Release notes
*************

This is the list of changes to puffbird between each release. For full details,
see the `commit logs <https://github.com/gucky92/puffbird/commits/>`_.

Version 0.0.0
-------------

.. toctree::
   :maxdepth: 2

   v0.0.1
